# **Coded**

## Coded is a programming language and Python extension designed to make programming just a little bit easier.

With Coded, you can easily build projects - no matter how complex.  
Our libraries allow you to create whatever you can imagine, with just a few lines of code.

## Documentation

<!--

``` python
write(*text, seperator="", end="", flush=True)
```

``` python
writeline(*text, seperator="", flush=True)
```

``` python
prompt()
```

``` python
clear()
```

``` python
rand()
```

``` python
readf(path)
```

``` python
writef(path, content)
```

``` python
appendf(path, content)
```

``` python
rm(path)
```

``` python
rmdir(path)
```

``` python
syscmd(cmd)
```

``` python
delay()
```

``` python
request_get()
```

``` python
request_get_cookies()
```

``` python
request_post()
```

``` python
request_post_content()
```

``` python
request_post_cookies()
```

``` python
getenv()
```

``` python
setenv()
```

``` python
get_working_dir()
```

``` python
hash_sha512()
```

``` python
hash_sha256()
```

``` python
hash_sha384()
```

``` python
hash_sha224()
```

``` python
hash_sha1()
```

``` python
hash_md5()
```

``` python
USERNAME
```

``` python
PID
```

``` python
UID
```

``` python
OS_TYPE
```

``` python
true
```

``` python
false
```

``` python
envs
```

``` python
pypath
```

``` python
Colour
```

``` python
Colour() *(constructor)*
```

``` python
Colour.RED
```

``` python
Colour.GREEN
```

``` python
Colour.BLUE
```

``` python
Colour.YELLOW
```

``` python
Colour.CYAN
```

``` python
Colour.MAGENTA
```

``` python
Colour.hex_to_rgb()
```

``` python
Colour.rgb_to_hex
```

``` python
*Colour.__str__()*
```

``` python
*Colour.__eq__()*
```

``` python
Ansi
```

``` python
Ansi.RESET
```

``` python
Ansi.FBLACK
```

``` python
Ansi.BBLACK
```

``` python
Ansi.RESET
```

``` python
Ansi.FBLACK
```

``` python
Ansi.BBLACK
```

``` python
Ansi.FRED
```

``` python
Ansi.BRED
```

``` python
Ansi.FGREEN
```

``` python
Ansi.BGREEN
```

``` python
Ansi.FBLUE
```

``` python
Ansi.BBLUE
```

``` python
Ansi.FYELLOW
```

``` python
Ansi.BYELLOW
```

``` python
Ansi.FCYAN
```

``` python
Ansi.BCYAN
```

``` python
Ansi.FMAGENTA
```

``` python
Ansi.BMAGENTA
```

``` python
Ansi.FWHITE
```

``` python
Ansi.BWHITE
```

``` python
Ansi.FLBLACK
```

``` python
Ansi.BLBLACK
```

``` python
Ansi.FLRED
```

``` python
Ansi.BLRED
```

``` python
Ansi.FLGREEN
```

``` python
Ansi.BLGREEN
```

``` python
Ansi.FLBLUE
```

``` python
Ansi.BLBLUE
```

``` python
Ansi.FLYELLOW
```

``` python
Ansi.BLYELLOW
```

``` python
Ansi.FLCYAN
```

``` python
Ansi.BLCYAN
```

``` python
Ansi.FLMAGENTA
```

``` python
Ansi.BLMAGENTA
```

``` python
Ansi.FLWHITE
```

``` python
Ansi.BLWHITE
```

``` python
Window
```

``` python
Window *(constructor)*
```

``` python
Window.run()
```

``` python
Window.quit_window()
```

``` python
Window.event()
```

``` python
Window.keydown()
```

``` python
Window.keyup()
```

``` python
Window.mousedown()
```

``` python
Window.mouseup()
```

``` python
Window.mousex()
```

``` python
Window.mousey()
```

``` python
Window.mousepos()
```

``` python
Window.keys_pressed()
```

``` python
Window.key_is_down()
```

``` python
Time
```

``` python
Time() *(constructor)*
```

``` python
Time.convert_time()
```

``` python
Time.get_real_time()
```

-->

[View the full documentation](https://github.com/dylanopen/coded.py)

## Current features:

* write()
* writeline()
* prompt()
* clear()
* rand()
* readf()
* writef()
* rm()
* rmdir()
* syscmd()
* delay()
* request_get()
* request_get_cookies()
* request_post()
* request_post_content()
* request_post_cookies()
* getenv()
* setenv()
* get_working_dir()
* hash_sha512()
* hash_sha256()
* hash_sha384()
* hash_sha224()
* hash_sha1()
* hash_md5()
* USERNAME *(property)*
* PID *(property)*
* UID *(property)*
* OS_TYPE *(property)*
* true *(property)*
* false *(property)*
* envs *(property)*
* pypath *(property)*
* Colour *(class)*
* Colour() *(constructor)*
* Colour.RED *(property)*
* Colour.GREEN *(property)*
* Colour.BLUE *(property)*
* Colour.YELLOW *(property)*
* Colour.CYAN *(property)*
* Colour.MAGENTA *(property)*
* Colour.hex_to_rgb()
* Colour.rgb_to_hex
* *Colour.__str__()*
* *Colour.__eq__()*
* Ansi *(class)*
* Ansi.RESET *(property)*
* Ansi.FBLACK *(property)*
* Ansi.BBLACK *(property)*
* Ansi.RESET *(property)*
* Ansi.FBLACK *(property)*
* Ansi.BBLACK *(property)*
* Ansi.FRED *(property)*
* Ansi.BRED *(property)*
* Ansi.FGREEN *(property)*
* Ansi.BGREEN *(property)*
* Ansi.FBLUE *(property)*
* Ansi.BBLUE *(property)*
* Ansi.FYELLOW *(property)*
* Ansi.BYELLOW *(property)*
* Ansi.FCYAN *(property)*
* Ansi.BCYAN *(property)*
* Ansi.FMAGENTA *(property)*
* Ansi.BMAGENTA *(property)*
* Ansi.FWHITE *(property)*
* Ansi.BWHITE *(property)*
* Ansi.FLBLACK *(property)*
* Ansi.BLBLACK *(property)*
* Ansi.FLRED *(property)*
* Ansi.BLRED *(property)*
* Ansi.FLGREEN *(property)*
* Ansi.BLGREEN *(property)*
* Ansi.FLBLUE *(property)*
* Ansi.BLBLUE *(property)*
* Ansi.FLYELLOW *(property)*
* Ansi.BLYELLOW *(property)*
* Ansi.FLCYAN *(property)*
* Ansi.BLCYAN *(property)*
* Ansi.FLMAGENTA *(property)*
* Ansi.BLMAGENTA *(property)*
* Ansi.FLWHITE *(property)*
* Ansi.BLWHITE *(property)*
* Window *(class)*
* Window *(constructor)*
* Window.run()
* Window.quit_window()
* Window.event()
* Window.keydown()
* Window.keyup()
* Window.mousedown()
* Window.mouseup()
* Window.mousex()
* Window.mousey()
* Window.mousepos()
* Window.keys_pressed()
* Window.key_is_down()
* Time *(class)*
* Time() *(constructor)*
* Time.convert_time()
* Time.get_real_time()

And MANY more!

## Changelog

1.1:

* Created basic project structure
* Created Coded
* Added `write`

1.2:

* Added `writeline`

1.3:

* Added `prompt`
* Reconfigured program structure
* Removed submodules (e.g. `console.write` is now just `write`)
* Added changelog
* Added project description
* Added documentation link
* Fixed `writeline` tuple bug

1.4:

* Use `os` module
* Added `clear`
* Added [current features](#current-features) view.

1.5:

* Added function documentation inline
* Handles exceptions in `prompt`

All newer minor versions:

* Bug fixes
* New features

[View full changelog](https://github.com/dylanopen/coded.py)
